JsonCheckboxBuilder class
Builder that can build an Checkbox widget. See the fromDynamic for the format.
- Inheritance
-
- Object
- JsonWidgetBuilder
- JsonCheckboxBuilder
Constructors
-
JsonCheckboxBuilder({Color? activeColor, required bool autofocus, AutovalidateMode? autovalidateMode, Color? checkColor, required bool enabled, MaterialStateProperty<
Color?> ? fillColor, Color? focusColor, FocusNode? focusNode, Color? hoverColor, String? label, MaterialTapTargetSize? materialTapTargetSize, MouseCursor? mouseCursor, ValueChanged<bool?> ? onChanged, ValueChanged<bool?> ? onSaved, MaterialStateProperty<Color?> ? overlayColor, OutlinedBorder? shape, BorderSide? side, double? splashRadius, required bool tristate, Validator? validator, bool? value, VisualDensity? visualDensity})
Properties
- activeColor → Color?
-
final
- autofocus → bool
-
final
- autovalidateMode → AutovalidateMode?
-
final
- checkColor → Color?
-
final
- enabled → bool
-
final
-
fillColor
→ MaterialStateProperty<
Color?> ? -
final
- focusColor → Color?
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverColor → Color?
-
final
- label → String?
-
final
- materialTapTargetSize → MaterialTapTargetSize?
-
final
- mouseCursor → MouseCursor?
-
final
- numSupportedChildren → int
-
finalinherited
-
onChanged
→ ValueChanged<
bool?> ? -
final
-
onSaved
→ ValueChanged<
bool?> ? -
final
-
overlayColor
→ MaterialStateProperty<
Color?> ? -
final
- preferredSizeWidget → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → OutlinedBorder?
-
final
- side → BorderSide?
-
final
- splashRadius → double?
-
final
- tristate → bool
-
final
- validator → Validator?
-
final
- value → bool?
-
final
- visualDensity → VisualDensity?
-
final
Methods
-
build(
{required ChildWidgetBuilder? childBuilder, required BuildContext context, required JsonWidgetData data}) → Widget -
Builds the widget. If there are dynamic keys on the
dataobject, and the widget is not a PreferredSizeWidget, then the returned widget will be wrapped by a stateful widget that will rebuild if any of the dynamic args change in value.inherited -
buildCustom(
{ChildWidgetBuilder? childBuilder, required BuildContext context, required JsonWidgetData data, Key? key}) → Widget -
Builds the widget to render to the tree. If the
dataobject has a non-emptyidassociated with it and the enabled property istruethen this will attach the selected value to the JsonWidgetRegistry using theidas the key any time the selected value is changed.override -
getChild(
JsonWidgetData? data, {int index = 0}) → JsonWidgetData -
Returns a non-null child for widgets that must always have child widgets.
This allows the widget to be built and rendered even if the child is
missing.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
JsonWidgetData data) → void -
Removes any / all values this builder may have set from the
JsonWidgetRegistry.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromDynamic(
dynamic map, {JsonWidgetRegistry? registry}) → JsonCheckboxBuilder? - Builds the builder from a Map-like dynamic structure. This expects the JSON format to be of the following structure:
Constants
- kNumSupportedChildren → const int
- type → const String