buildCustom method
Widget
buildCustom({
- ChildWidgetBuilder? childBuilder,
- required BuildContext context,
- required JsonWidgetData data,
- Key? key,
override
Custom builder that subclasses must override and implement to return the actual Widget to be placed on the tree.
Implementation
@override
Widget buildCustom({
ChildWidgetBuilder? childBuilder,
required BuildContext context,
required JsonWidgetData data,
Key? key,
}) {
var child = getChild(data);
return PopupMenuButton(
color: color,
elevation: elevation,
enableFeedback: enableFeedback,
enabled: enabled,
icon: icon?.build(
childBuilder: childBuilder,
context: context,
),
iconSize: iconSize,
initialValue: initialValue,
itemBuilder: itemBuilder,
key: key,
offset: offset,
onCanceled: onCanceled,
onSelected: onSelected,
padding: padding,
shape: shape,
tooltip: tooltip,
child: child.build(
childBuilder: childBuilder,
context: context,
),
);
}