buildCustom method

  1. @override
Widget buildCustom({
  1. ChildWidgetBuilder? childBuilder,
  2. required BuildContext context,
  3. required JsonWidgetData data,
  4. Key? key,
})
override

Custom builder that subclasses must override and implement to return the actual Widget to be placed on the tree.

Implementation

@override
Widget buildCustom({
  ChildWidgetBuilder? childBuilder,
  required BuildContext context,
  required JsonWidgetData data,
  Key? key,
}) {
  var child = getChild(data);

  return RaisedButton(
    animationDuration: animationDuration,
    autofocus: autofocus,
    clipBehavior: clipBehavior,
    color: color,
    colorBrightness: colorBrightness,
    disabledColor: disabledColor,
    disabledElevation: disabledElevation,
    disabledTextColor: disabledTextColor,
    elevation: elevation,
    focusColor: focusColor,
    focusElevation: focusElevation,
    focusNode: focusNode,
    highlightColor: highlightColor,
    highlightElevation: highlightElevation,
    hoverColor: hoverColor,
    hoverElevation: hoverElevation,
    key: key,
    materialTapTargetSize: materialTapTargetSize,
    mouseCursor: mouseCursor,
    onHighlightChanged: onHighlightChanged,
    onPressed: onPressed,
    onLongPress: onLongPress,
    padding: padding,
    shape: shape,
    splashColor: splashColor,
    textColor: textColor,
    textTheme: textTheme,
    visualDensity: visualDensity,
    child: child.build(
      childBuilder: childBuilder,
      context: context,
    ),
  );
}