buildCustom method

  1. @override
Widget buildCustom({
  1. ChildWidgetBuilder? childBuilder,
  2. required BuildContext context,
  3. required JsonWidgetData data,
  4. Key? key,
})
override

Custom builder that subclasses must override and implement to return the actual Widget to be placed on the tree.

Implementation

@override
Widget buildCustom({
  ChildWidgetBuilder? childBuilder,
  required BuildContext context,
  required JsonWidgetData data,
  Key? key,
}) {
  var child = getChild(data);

  return Testable(
    id: data.id,
    onRequestError: onRequestError,
    onRequestValue: onRequestValue,
    onSetValue: onSetValue,
    scrollableId: scrollableId,
    child: data.children?.length != 1
        ? SizedBox()
        : child.build(
            childBuilder: childBuilder,
            context: context,
          ),
  );
}