JsonWidgetBuilderContainer class
Container for a JsonWidgetBuilder builder as well as an associated schema
id. The schema id will be used to validate the JSON args against the
schema if it is not null. If it is null, no schema validation will be
performed against the JSON for this particular builder.
Constructors
- JsonWidgetBuilderContainer({required JsonWidgetBuilderBuilder builder, String? schemaId})
-
const
Properties
- builder → JsonWidgetBuilderBuilder
-
The builder that will create the JsonWidgetBuilder from JSON.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaId → String?
-
Optional schemaId. Either the schema must be registered against the
SchemaCacheor an error will happen when the validation is attempted.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited