getValue method

dynamic getValue(
  1. String? key
)

Returns the variable value for the given key.This will first check for a custom dynamic value using the key, and if none is found, this will then check the internal values. If a variable with named key cannot be found, this will return null.

Implementation

dynamic getValue(String? key) => _values[key] ?? _internalValues[key!];