navigatorKey property
A navigator key that is required in order to use the
fun_key_navigate_named and fun_key_navigate_pop functions. This holds
the navigator state that will be used to push the named route to the
stack.
For the key to be useful, it must have been also passed to an object that maintains a navigation stack, such as a MaterialApp. Example:
MaterialApp(
navigatorKey: navigatorKey
)
Implementation
GlobalKey<NavigatorState>? navigatorKey;