removeValue method

dynamic removeValue(
  1. String key
)

Removes the key from the registry.

If, and only if, the key was registered on the registry will this fire an event on the valueStream with the key so listeners can be notified that the value has changed.

Implementation

dynamic removeValue(String key) {
  assert(key.isNotEmpty == true);

  var hasKey = _values.containsKey(key);
  var result = _values.remove(key);
  if (hasKey == true) {
    _valueStreamController?.add(key);
  }

  return result;
}