MapArgProcessor class
Processor for map arg. It is entry point for JsonWidgetData args.
If the arg is detected to be JsonWidgetData then processing of such
an arg is skipped.
The processor is processing every key/value of the arg using
JsonWidgetRegistry processsors and it is aggregating all
listen variable names. In case of passing listenVariables directly
then the aggregation step is skipped.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
JsonWidgetRegistry registry, dynamic arg, Set< String> ? listenVariables) → ProcessedArg -
Process passed
arginto ProcessedArg. Theregistryis giving functions and variables information context for the processing.override -
support(
dynamic arg) → bool -
Used to give the information if specified
argis supported by ArgProcessor.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited