json_dynamic_widget_annotation library
Classes
- AlignmentConverter
- AppBarThemeConverter
- AutovalidateModeConverter
- AxisConverter
- BlendModeConverter
- BorderRadiusConverter
- BorderSideConverter
- BorderStyleConverter
- BottomAppBarThemeConverter
- BottomSheetThemeDataConverter
- BoxBorderConverter
- BoxConstraintsConverter
- BoxDecorationConverter
- BoxFitConverter
- BoxShadowConverter
- BoxShapeConverter
- BrightnessConverter
- ButtonBarLayoutBehaviorConverter
- ButtonBarThemeDataConverter
- ButtonStyleConverter
- ButtonTextThemeConverter
- ButtonThemeDataConverter
- CardThemeConverter
- CheckboxThemeDataConverter
- ChipThemeDataConverter
- ClipConverter
- ColorConverter
- ColorSchemeConverter
- CrossAxisAlignmentConverter
- CrossFadeStateConverter
- CupertinoTextThemeDataConverter
- CupertinoThemeDataConverter
- CurvesValues
- DataTableThemeDataConverter
- DecorationImageConverter
- DecorationPositionConverter
- DeferredJsonWidgetData
- A JsonWidgetData subclass that does not parse the JSON until the values are needed. This is used internally by the library for when widgets are requested through a variable reference because the variable often won't exist until after the first pass of the widget tree processing is completed.
- DialogThemeConverter
- DividerThemeDataConverter
- DragStartBehaviorConverter
- DynamicParamsResult
- DynamicValuesFactory
-
Creates values used to parameterize child templates.
It generates 'id' field if not exist via
Uuid.v4. - EdgeInsetsGeometryConverter
- ElevatedButtonThemeDataConverter
- FilterQualityConverter
- FlexFitConverter
- FloatingActionButtonAnimatorConverter
- FloatingActionButtonLocationConverter
- FloatingActionButtonThemeDataConverter
- FloatingLabelBehaviorConverter
- FontFeatureConverter
- FontStyleConverter
- FontWeightConverter
- GradientConverter
- GradientTransformConverter
- HitTestBehaviorConverter
- IconDataConverter
- IconThemeDataConverter
- ImageProviderConverter
- ImageRepeatConverter
- InputBorderConverter
- InputDecorationDecoder
- InputDecorationThemeConverter
- InputError
- InteractiveInkFeatureFactoryConverter
- JsonAlignBuilder
- Builder that can build an Align widget. See the fromDynamic for the format.
- JsonAnimatedAlignBuilder
- Builder that can build an AnimatedAlign widget. See the fromDynamic for the format.
- JsonAnimatedContainerBuilder
- Builder that can build an AnimatedContainer widget. See the fromDynamic for the format.
- JsonAnimatedCrossFadeBuilder
- Builder that can build an AnimatedCrossFade widget. See the fromDynamic for the format. The ordering of the children in JSON determines which will be the first or second to be rendered.
- JsonAnimatedDefaultTextStyleBuilder
- Builder that can build an AnimatedDefaultTextStyle widget. See the fromDynamic for the format.
- JsonAnimatedOpacityBuilder
- Builder that can build an AnimatedOpacity widget. See the fromDynamic for the format.
- JsonAnimatedPaddingBuilder
- Builder that can build an AnimatedPadding widget. See the fromDynamic for the format.
- JsonAnimatedPhysicalModelBuilder
- Builder that can build an AnimatedPhysicalModel widget. See the fromDynamic for the format.
- JsonAnimatedPositionedBuilder
- Builder that can build an AnimatedPositioned widget. See the fromDynamic for the format.
- JsonAnimatedPositionedDirectionalBuilder
- Builder that can build an AnimatedPositionedDirectional widget. See the fromDynamic for the format.
- JsonAnimatedSizeBuilder
- Builder that can build an AnimatedSize widget. See the fromDynamic for the format.
- JsonAnimatedSwitcherBuilder
- Builder that can build an AnimatedSwitcher widget. See the fromDynamic for the format.
- JsonAnimatedThemeBuilder
- Builder that can build an AnimatedTheme widget. See the fromDynamic for the format.
- JsonAppBarBuilder
- Builder that can build an AppBar widget. See the fromDynamic for the format.
- JsonAspectRatioBuilder
- Builder that can build an AspectRatio widget. See the fromDynamic for the format.
- JsonAssetImageBuilder
- Builder that can build an Image widget using bundled assets. See the fromDynamic for the format.
- JsonBaselineBuilder
- Builder that can build an Baseline widget. See the fromDynamic for the format.
- JsonButtonBarBuilder
- Builder that can build an ButtonBar widget. See the fromDynamic for the format.
- JsonCardBuilder
- Builder that can build an Card widget. See the fromDynamic for the format.
- JsonCenterBuilder
- Builder that can build an Center widget. See the fromDynamic for the format.
- JsonCheckboxBuilder
- Builder that can build an Checkbox widget. See the fromDynamic for the format.
- JsonCircularProgressIndicatorBuilder
- Builder that can build an CircularProgressIndicator widget. See the fromDynamic for the format.
- JsonClipOvalBuilder
- Builder that can build an ClipOval widget. See the fromDynamic for the format.
- JsonClipPathBuilder
- Builder that can build an ClipPath widget. See the fromDynamic for the format.
- JsonClipRectBuilder
- Builder that can build an ClipRect widget. See the fromDynamic for the format.
- JsonClipRRectBuilder
- Builder that can build an ClipRRect widget. See the fromDynamic for the format.
- JsonColumnBuilder
- Builder that can build an Column widget. See the fromDynamic for the format.
- JsonConditionalBuilder
- Builder that builds either the actual child widget or clears the child widgets based on the result from the conditional.
- JsonContainerBuilder
- Builder that can build an Container widget. See the fromDynamic for the format.
-
JsonConverter<
T, S> - Implement this class to provide custom converters for a specific Type.
- JsonCupertinoSwitchBuilder
- Builder that can build an CupertinoSwitch widget. See the fromDynamic for the format.
- JsonDecoratedBoxBuilder
- Builder that can build an DecoratedBox widget. See the fromDynamic for the format.
- JsonDirectionalityBuilder
- Builder that can build a Directionality widget. See the fromDynamic for the format.
- JsonDropdownButtonFormFieldBuilder
- Builder that can build an DropdownButtonFormField widget. See the fromDynamic for the format.
- JsonDynamicBuilder
-
Builder that builds children based on the state the listened value.
Listened value name is equal to
idfield value. Children are created fromchildTemplatewith usage of##dynamic##function.childTemplateis able to use template values via {} format. For example to use anidvalue in a template just putting there{id}is enough. Templating mechanism usesInterpolationunderneath. - JsonDynamicWidgetAnnotation
- JsonElevatedButtonBuilder
- Builder that can build an ElevatedButton widget. See the fromDynamic for the format.
- JsonEnum
-
Allows configuration of how
enumelements are treated as JSON. - JsonExcludeSemanticsBuilder
- Builder that can build an MergeSemantics widget. See the fromDynamic for the format.
- JsonExpandedBuilder
- Builder that can build an Expanded widget. See the fromDynamic for the format.
- JsonFittedBoxBuilder
- Builder that can build an FittedBox widget. See the fromDynamic for the format.
- JsonFlatButtonBuilder
-
Builder that can build an
FlatButtonwidget. See the fromDynamic for the format. - JsonFlexibleBuilder
- Builder that can build an Flexible widget. See the fromDynamic for the format.
- JsonFloatingActionButtonBuilder
- Builder that can build a FloatingActionButton widget. See the fromDynamic for the format.
- JsonFormBuilder
- Builder that can build an Form widget. See the fromDynamic for the format.
- JsonFractionallySizedBoxBuilder
- Builder that can build a FractionallySizedBox widget. See the fromDynamic for the format.
- JsonFractionalTranslationBuilder
- Builder that can build a FractionalTranslation widget. See the fromDynamic for the format.
- JsonGestureDetectorBuilder
- Builder that can build an GestureDetector widget. See the fromDynamic for the format.
- JsonHeroBuilder
- Builder that can build an Hero widget. See the fromDynamic for the format.
- JsonIconBuilder
- Builder that can build an Icon widget. See the fromDynamic for the format.
- JsonIconButtonBuilder
- Builder that can build an IconButton widget. See the fromDynamic for the format.
- JsonIgnorePointerBuilder
- Builder that can build an IgnorePointer widget. See the fromDynamic for the format.
- JsonIndexedStackBuilder
- Builder that can build an IndexedStack widget. See the fromDynamic for the format.
- JsonInkWellBuilder
- Builder that can build an InkWell widget. See the fromDynamic for the format.
- JsonInputErrorBuilder
- Builder that can build an InputError widget. See the fromDynamic for the format.
- JsonInteractiveViewerBuilder
- Builder that can build an InteractiveViewer widget. See the fromDynamic for the format.
- JsonIntrinsicHeightBuilder
- Builder that can build an IntrinsicHeight widget. See the fromDynamic for the format.
- JsonIntrinsicWidthBuilder
- Builder that can build an IntrinsicWidth widget. See the fromDynamic for the format.
- JsonKey
- An annotation used to specify how a field is serialized.
- JsonLayoutBuilderBuilder
- Builder that can build an LayoutBuilder widget. See the fromDynamic for the format.
- JsonLimitedBoxBuilder
- Builder that can build a LimitedBox widget. See the fromDynamic for the format.
- JsonLinearProgressIndicatorBuilder
- Builder that can build an LinearProgressIndicator widget. See the fromDynamic for the format.
- JsonListTileBuilder
- Builder that can build an ListTile widget. See the fromDynamic for the format.
- JsonListViewBuilder
- Builder that can build an ListView widget. See the fromDynamic for the format.
- JsonLiteral
- An annotation used to generate a private field containing the contents of a JSON file.
- JsonMaterialBuilder
- Builder that can build an Material widget. See the fromDynamic for the format.
- JsonMeasuredBuilder
- Builder that can build a widget that measures itself and writes the measurements to the JsonWidgetRegistry's values. See the fromDynamic for the format.
- JsonMemoryImageBuilder
- Builder that can build an Image widget from memory. See the fromDynamic for the format.
- JsonMergeSemanticsBuilder
- Builder that can build an MergeSemantics widget. See the fromDynamic for the format.
- JsonNetworkImageBuilder
- Builder that can build an Image widget from a network URL. See the fromDynamic for the format.
- JsonOffstageBuilder
- Builder that can build an Offstage widget. See the fromDynamic for the format.
- JsonOpacityBuilder
- Builder that can build an Opacity widget. See the fromDynamic for the format.
- JsonOutlinedButtonBuilder
- Builder that can build an OutlinedButton widget. See the fromDynamic for the format.
- JsonOverflowBoxBuilder
- Builder that can build an OverflowBox widget. See the fromDynamic for the format.
- JsonPaddingBuilder
- Builder that can build an Padding widget. See the fromDynamic for the format.
- JsonPlaceholderBuilder
- Builder that can build a Placeholder widget. See the fromDynamic for the format.
- JsonPopupMenuButtonBuilder
- Builder that can build a PopupMenuButton widget. See the fromDynamic for the format.
- JsonPositionedBuilder
- Builder that can build an Positioned widget. See the fromDynamic for the format.
- JsonRadioBuilder
-
Builder that can build an Radio See the fromDynamic for the
format. Unlike other form fields, this requires the
idfor the radio variable to be inside of theargs. This is because no two widgets can share the same overall id. - JsonRaisedButtonBuilder
-
Builder that can build an
RaisedButtonwidget. See the fromDynamic for the format. - JsonRowBuilder
- Builder that can build an Row widget. See the fromDynamic for the format.
- JsonSafeAreaBuilder
- Builder that can build an SafeArea widget. See the fromDynamic for the format.
- JsonSaveContextBuilder
- Builder that sets a the current BuildContext on the JsonWidgetRegistry. This doesn't actually have a widget and instead simply returns the child's built widget. See the fromDynamic for the format.
- JsonScaffoldBuilder
- Builder that can build an Scaffold widget. See the fromDynamic for the format.
- JsonSemanticsBuilder
- Builder that can build an Semantics widget. See the fromDynamic for the format.
- JsonSerializable
- An annotation used to specify a class to generate code for.
- JsonSetValueBuilder
- Builder that sets a value (or group of values) to the JsonWidgetRegistry. This doesn't actually have a widget and instead simply returns the child's built widget. See the fromDynamic for the format.
- JsonSetWidgetBuilder
- Builder that sets a value (or group of values) to the JsonWidgetRegistry. This doesn't actually have a widget and instead simply returns the child's built widget. See the fromDynamic for the format.
- JsonSingleChildScrollViewBuilder
- Builder that can build an SingleChildScrollView widget. See the fromDynamic for the format.
- JsonSizedBoxBuilder
- Builder that can build an SizedBox widget. See the fromDynamic for the format.
- JsonStackBuilder
- Builder that can build an Stack widget. See the fromDynamic for the format.
- JsonSwitchBuilder
- Builder that can build an Switch widget. See the fromDynamic for the format.
- JsonTestableBuilder
- Builder that can build an SizedBox widget. See the fromDynamic for the format.
- JsonTextBuilder
- Builder that can build an Text widget. See the fromDynamic for the format.
- JsonTextButtonBuilder
- Builder that can build a TextButton widget. See the fromDynamic for the format.
- JsonTextFormFieldBuilder
- Builder that can build an TextFormField widget. See the fromDynamic for the format.
- JsonThemeBuilder
- Builder that can build an Theme widget. See the fromDynamic for the format.
- JsonTweenAnimationBuilder
- Builder that can build an TweenAnimationBuilder widget. See the fromDynamic for the format.
- JsonValue
- An annotation used to specify how a enum value is serialized.
- JsonWidgetBuilder
- Builder that builds dynamic widgets from JSON or other Map-like structures. Applications can register their own types and builders through the JsonWidgetRegistry.
- JsonWidgetBuilderContainer
-
Container for a JsonWidgetBuilder builder as well as an associated schema
id. The schema id will be used to validate the JSON args against the
schema if it is not
null. If it isnull, no schema validation will be performed against the JSON for this particular builder. - JsonWidgetData
- JsonWidgetParams
- JsonWidgetRegexHelper
- JsonWidgetRegistry
- Registry for both the library provided as well as custom form builders that the application may provide.
- JsonWidgetType
- LocaleConverter
- MainAxisAlignmentConverter
- MainAxisSizeConverter
- MaterialBannerThemeDataConverter
- MaterialColorConverter
- MaterialStatePropertyBorderSideConverter
- MaterialStatePropertyColorConverter
- MaterialStatePropertyDoubleConverter
- MaterialStatePropertyEdgeInsetsGeometryConverter
- MaterialStatePropertyMouseCursorConverter
- MaterialStatePropertyOutlinedBorderConverter
- MaterialStatePropertySizeConverter
- MaterialStatePropertyTextStyleConverter
- MaterialTapTargetSizeConverter
- MaterialTypeConverter
- MaxLengthEnforcementConverter
- MouseCursorConverter
- NotchedShapeConverter
- NullableAlignmentConverter
- NullableAppBarThemeConverter
- NullableAutovalidateModeConverter
- NullableAxisConverter
- NullableBlendModeConverter
- NullableBorderRadiusConverter
- NullableBorderSideConverter
- NullableBorderStyleConverter
- NullableBottomAppBarThemeConverter
- NullableBottomSheetThemeDataConverter
- NullableBoxBorderConverter
- NullableBoxConstraintsConverter
- NullableBoxDecorationConverter
- NullableBoxFitConverter
- NullableBoxShadowConverter
- NullableBoxShapeConverter
- NullableBrightnessConverter
- NullableButtonBarLayoutBehaviorConverter
- NullableButtonBarThemeDataConverter
- NullableButtonStyleConverter
- NullableButtonTextThemeConverter
- NullableButtonThemeDataConverter
- NullableCardThemeConverter
- NullableCheckboxThemeDataConverter
- NullableChipThemeDataConverter
- NullableClipConverter
- NullableColorConverter
- NullableColorSchemeConverter
- NullableCrossAxisAlignmentConverter
- NullableCrossFadeStateConverter
- NullableCupertinoTextThemeDataConverter
- NullableCupertinoThemeDataConverter
- NullableDataTableThemeDataConverter
- NullableDecorationImageConverter
- NullableDecorationPositionConverter
- NullableDialogThemeConverter
- NullableDividerThemeDataConverter
- NullableDragStartBehaviorConverter
- NullableEdgeInsetsGeometryConverter
- NullableElevatedButtonThemeDataConverter
- NullableFilterQualityConverter
- NullableFlexFitConverter
- NullableFloatingActionButtonAnimatorConverter
- NullableFloatingActionButtonLocationConverter
- NullableFloatingActionButtonThemeDataConverter
- NullableFloatingLabelBehaviorConverter
- NullableFontFeatureConverter
- NullableFontStyleConverter
- NullableFontWeightConverter
- NullableGradientConverter
- NullableGradientTransformConverter
- NullableHitTestBehaviorConverter
- NullableIconDataConverter
- NullableIconThemeDataConverter
- NullableImageProviderConverter
- NullableImageRepeatConverter
- NullableInputBorderConverter
- NullableInputDecorationThemeConverter
- NullableInteractiveInkFeatureFactoryConverter
- NullableLocaleConverter
- NullableMainAxisAlignmentConverter
- NullableMainAxisSizeConverter
- NullableMaterialBannerThemeDataConverter
- NullableMaterialColorConverter
- NullableMaterialStatePropertyBorderSideConverter
- NullableMaterialStatePropertyColorConverter
- NullableMaterialStatePropertyDoubleConverter
- NullableMaterialStatePropertyEdgeInsetsGeometryConverter
- NullableMaterialStatePropertyMouseCursorConverter
- NullableMaterialStatePropertyOutlinedBorderConverter
- NullableMaterialStatePropertySizeConverter
- NullableMaterialStatePropertyTextStyleConverter
- NullableMaterialTapTargetSizeConverter
- NullableMaterialTypeConverter
- NullableMaxLengthEnforcementConverter
- NullableMouseCursorConverter
- NullableNotchedShapeConverter
- NullableOffsetConverter
- NullableOrdinalSortKeyConverter
- NullableOutlinedBorderConverter
- NullableOutlinedButtonThemeDataConverter
- NullableOverflowConverter
- NullablePageTransitionsBuilderConverter
- NullablePageTransitionsThemeConverter
- NullablePopupMenuThemeDataConverter
- NullableRadioThemeDataConverter
- NullableRadiusConverter
- NullableRangeSliderThumbShapeConverter
- NullableRangeSliderTickMarkShapeConverter
- NullableRangeSliderTrackShapeConverter
- NullableRangeSliderValueIndicatorShapeConverter
- NullableRectConverter
- NullableScrollbarThemeDataConverter
- NullableScrollPhysicsConverter
- NullableScrollViewKeyboardDismissBehaviorConverter
- NullableSemanticsTagConverter
- NullableShadowConverter
- NullableShapeBorderConverter
- NullableShowValueIndicatorConverter
- NullableSizeConverter
- NullableSliderComponentShapeConverter
- NullableSliderThemeDataConverter
- NullableSliderTickMarkShapeConverter
- NullableSliderTrackShapeConverter
- NullableSmartDashesTypeConverter
- NullableSmartQuotesTypeConverter
- NullableSnackBarBehaviorConverter
- NullableSnackBarThemeDataConverter
- NullableStackFitConverter
- NullableStrutStyleConverter
- NullableSwitchThemeDataConverter
- NullableSystemUiOverlayStyleConverter
- NullableTabBarIndicatorSizeConverter
- NullableTabBarThemeConverter
- NullableTargetPlatformConverter
- NullableTextAlignConverter
- NullableTextAlignVerticalConverter
- NullableTextBaselineConverter
- NullableTextButtonThemeDataConverter
- NullableTextCapitalizationConverter
- NullableTextDecorationConverter
- NullableTextDecorationStyleConverter
- NullableTextDirectionConverter
- NullableTextHeightBehaviorConverter
- NullableTextInputActionConverter
- NullableTextInputTypeConverter
- NullableTextOverflowConverter
- NullableTextSelectionThemeDataConverter
- NullableTextStyleConverter
- NullableTextThemeConverter
- NullableTextWidthBasisConverter
- NullableThemeDataConverter
- NullableTileModeConverter
- NullableTimePickerThemeDataConverter
- NullableToggleButtonsThemeDataConverter
- NullableToolbarOptionsConverter
- NullableTooltipThemeDataConverter
- NullableTypographyConverter
- NullableVerticalDirectionConverter
- NullableVisualDensityConverter
- OffsetConverter
- OrdinalSortKeyConverter
- OutlinedBorderConverter
- OutlinedButtonThemeDataConverter
- OverflowConverter
- PageTransitionsBuilderConverter
- PageTransitionsThemeConverter
- PopupMenuThemeDataConverter
- RadioThemeDataConverter
- RadiusConverter
- RangeSliderThumbShapeConverter
- RangeSliderTickMarkShapeConverter
- RangeSliderTrackShapeConverter
- RangeSliderValueIndicatorShapeConverter
- RectConverter
- ScrollbarThemeDataConverter
- ScrollPhysicsConverter
- ScrollViewKeyboardDismissBehaviorConverter
- SemanticsTagConverter
- ShadowConverter
- ShapeBorderConverter
- ShowValueIndicatorConverter
- SizeConverter
- SliderComponentShapeConverter
- SliderThemeDataConverter
- SliderTickMarkShapeConverter
- SliderTrackShapeConverter
- SmartDashesTypeConverter
- SmartQuotesTypeConverter
- SnackBarBehaviorConverter
- SnackBarThemeDataConverter
- StackFitConverter
- StrutStyleConverter
- SwitchThemeDataConverter
- SystemUiOverlayStyleConverter
- TabBarIndicatorSizeConverter
- TabBarThemeConverter
- TargetPlatformConverter
- TextAlignConverter
- TextAlignVerticalConverter
- TextBaselineConverter
- TextButtonThemeDataConverter
- TextCapitalizationConverter
- TextDecorationConverter
- TextDecorationStyleConverter
- TextDirectionConverter
- TextHeightBehaviorConverter
- TextInputActionConverter
- TextInputTypeConverter
- TextOverflowConverter
- TextSelectionThemeDataConverter
- TextStyleConverter
- TextThemeConverter
- TextWidthBasisConverter
- ThemeDataConverter
- TileModeConverter
- TimePickerThemeDataConverter
- ToggleButtonsThemeDataConverter
- ToolbarOptionsConverter
- TooltipThemeDataConverter
- TypographyConverter
- VerticalDirectionConverter
- VisualDensityConverter
Enums
- FieldRename
- Values for the automatic field renaming behavior for JsonSerializable.
Functions
-
$checkedConvert<
T> (Map map, String key, T castFunc(dynamic), {Object? readValue(Map, String)?}) → T -
Helper function used in generated code when
JsonSerializableGenerator.checkedistrue. -
$checkedCreate<
T> (String className, Map map, T constructor(S < S>(String, S (Object?), {Object? readValue(Map, String)?}) ), {Map<String, String> fieldKeyMap = const {}}) → T -
Helper function used in generated code when
JsonSerializableGenerator.checkedistrue. -
$checkedNew<
T> (String className, Map map, T constructor(), {Map< String, String> ? fieldKeyMap}) → T -
Helper function used in generated code when
JsonSerializableGenerator.checkedistrue. -
$checkKeys(
Map map, {List< String> ? allowedKeys, List<String> ? requiredKeys, List<String> ? disallowNullValues}) → void -
Helper function used in generated
fromJsoncode whenJsonSerializable.disallowUnrecognizedKeysis true for an annotated type orJsonKey.requiredistruefor any annotated fields. -
$enumDecode<
K extends Enum, V> (Map< K, V> enumValues, Object? source, {K? unknownValue}) → K -
Returns the key associated with value
sourcefromenumValues, if one exists. -
$enumDecodeNullable<
K extends Enum, V> (Map< K, V> enumValues, Object? source, {Enum? unknownValue}) → K? -
Returns the key associated with value
sourcefromenumValues, if one exists.
Typedefs
- DeferredBuilder = JsonWidgetBuilder Function(JsonWidgetBuilderBuilder builder)
- JsonWidgetBuilderBuilder = JsonWidgetBuilder? Function(dynamic map, {JsonWidgetRegistry? registry})
- JsonWidgetFunction = FutureOr Function({required List? args, required JsonWidgetRegistry registry})
Exceptions / Errors
- BadKeyException
- A base class for exceptions thrown when decoding JSON.
- CheckedFromJsonException
-
Exception thrown if there is a runtime exception in
fromJsoncode generated whenJsonSerializableGenerator.checkedistrue - DisallowedNullValueException
-
Exception thrown if there are keys with disallowed
nullvalues in a JSON map that was provided during deserialization. - MissingRequiredKeysException
- Exception thrown if there are missing required keys in a JSON map that was provided during deserialization.
- UnrecognizedKeysException
- Exception thrown if there are unrecognized keys in a JSON map that was provided during deserialization.