DynamicParamsResult class
- Annotations
Constructors
-
DynamicParamsResult({Set<
String> ? dynamicKeys, required dynamic values}) -
const
Properties
-
dynamicKeys
→ Set<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- values → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override